@@ -3,12 +3,12 @@ use utf8;
 use Moo;
 extends 'NewsExtractor::GenericExtractor';
 
-use Importer 'NewsExtractor::TextUtil'  => qw(normalize_whitespace parse_dateline_ymdhms);
+use Importer 'NewsExtractor::TextUtil'  => qw(normalize_whitespace reformat_dateline);
 
 sub dateline {
     my ($self) = @_;
     my $el = $self->dom->at('span.info i') or return;
-    return parse_dateline_ymdhms( $el->all_text(), '+08:00' );
+    return reformat_dateline( $el->all_text(), '+08:00' );
 }
 
 sub journalist {
